import CTABox from './CTABox';
import Comment from './Comment';
import ContentTitle from './ContentTitle';
import MainForm from './forms/MainForm';
import Pagination from './Pagination';
import {ROOT_DIV_ID} from '../../utils/constants';
import {useAppContext, useLabs} from '../../AppContext';
import {useEffect} from 'react';

const Content = () => {
    const {pagination, member, comments, commentCount, commentsEnabled, title, showCount, secundaryFormCount} = useAppContext();
    const commentsElements = comments.slice().reverse().map(comment => <Comment key={comment.id} comment={comment} />);
    const labs = useLabs();

    useEffect(() => {
        const elem = document.getElementById(ROOT_DIV_ID);

        // Check scroll position
        if (elem && window.location.hash === `#ghost-comments`) {
            // Only scroll if the user didn't scroll by the time we loaded the comments
            // We could remove this, but if the network connection is slow, we risk having a page jump when the user already started scrolling
            if (window.scrollY === 0) {
                // This is a bit hacky, but one animation frame is not enough to wait for the iframe height to have changed and the DOM to be updated correctly before scrolling
                requestAnimationFrame(() => {
                    requestAnimationFrame(() => {
                        elem.scrollIntoView();
                    });
                });
            }
        }
    }, []);

    const isPaidOnly = commentsEnabled === 'paid';
    const isPaidMember = member && !!member.paid;

    const showCTA = !member || (isPaidOnly && !isPaidMember);
    const hasOpenReplyForms = secundaryFormCount > 0;

    return (
        <>
            <ContentTitle count={commentCount} showCount={showCount} title={title}/>
            <Pagination />
            <div className={!pagination ? 'mt-4' : ''} data-test="comment-elements">
                {commentsElements}
            </div>
            <div>
                {hasOpenReplyForms
                    ? null
                    : showCTA
                        ? <CTABox isFirst={pagination?.total === 0} isPaid={isPaidOnly} />
                        : <MainForm commentsCount={commentCount} />
                }
            </div>
            {
                labs?.testFlag ? <div data-testid="this-comes-from-a-flag" style={{display: 'none'}}></div> : null
            }
        </>
    );
};

export default Content;
